[polly] r235380 - Rename 'scattering' to 'schedule'

Tobias Grosser tobias at grosser.es
Tue Apr 21 04:37:26 PDT 2015


Author: grosser
Date: Tue Apr 21 06:37:25 2015
New Revision: 235380

URL: http://llvm.org/viewvc/llvm-project?rev=235380&view=rev
Log:
Rename 'scattering' to 'schedule'

In Polly we used both the term 'scattering' and the term 'schedule' to describe
the execution order of a statement without actually distinguishing between them.
We now uniformly use the term 'schedule' for the execution order.  This
corresponds to the terminology of isl.

History: CLooG introduced the term scattering as the generated code can be used
as a sequential execution order (schedule) or as a parallel dimension
enumerating different threads of execution (placement). In Polly and/or isl the
term placement was never used, but we uniformly refer to an execution order as a
schedule and only later introduce parallelism. When doing so we do not talk
about about specific placement dimensions.

Modified:
    polly/trunk/include/polly/DependenceInfo.h
    polly/trunk/include/polly/ScopInfo.h
    polly/trunk/lib/Analysis/DependenceInfo.cpp
    polly/trunk/lib/Analysis/ScopInfo.cpp
    polly/trunk/lib/CodeGen/IslCodeGeneration.cpp
    polly/trunk/lib/Exchange/JSONExporter.cpp
    polly/trunk/lib/Transform/ScheduleOptimizer.cpp
    polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_1.ll
    polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_2.ll
    polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_3.ll
    polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_nested.ll
    polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_surrounding_affine_loop.ll
    polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_surrounding_non_affine_loop.ll
    polly/trunk/test/ScopInfo/NonAffine/non_affine_float_compare.ll
    polly/trunk/test/ScopInfo/NonAffine/non_affine_loop_condition.ll
    polly/trunk/test/ScopInfo/NonAffine/non_affine_loop_used_later.ll
    polly/trunk/test/ScopInfo/NonAffine/non_affine_parametric_loop.ll
    polly/trunk/test/ScopInfo/loop_affine_bound_0.ll
    polly/trunk/test/ScopInfo/loop_affine_bound_1.ll
    polly/trunk/test/ScopInfo/loop_affine_bound_2.ll
    polly/trunk/test/ScopInfo/loop_carry.ll
    polly/trunk/test/ScopInfo/multidim_2d-diagonal-matrix.ll
    polly/trunk/test/ScopInfo/multidim_2d_outer_parametric_offset.ll
    polly/trunk/test/ScopInfo/multidim_2d_parametric_array_static_loop_bounds.ll
    polly/trunk/test/ScopInfo/multidim_3d_parametric_array_static_loop_bounds.ll
    polly/trunk/test/ScopInfo/multidim_ivs_and_integer_offsets_3d.ll
    polly/trunk/test/ScopInfo/multidim_ivs_and_parameteric_offsets_3d.ll
    polly/trunk/test/ScopInfo/multidim_nested_start_integer.ll
    polly/trunk/test/ScopInfo/multidim_only_ivs_2d.ll
    polly/trunk/test/ScopInfo/multidim_only_ivs_3d.ll
    polly/trunk/test/ScopInfo/multidim_only_ivs_3d_cast.ll
    polly/trunk/test/ScopInfo/multidim_only_ivs_3d_reverse.ll
    polly/trunk/test/ScopInfo/non_affine_region_1.ll
    polly/trunk/test/ScopInfo/non_affine_region_2.ll
    polly/trunk/test/ScopInfo/non_affine_region_3.ll
    polly/trunk/test/ScopInfo/non_affine_region_4.ll
    polly/trunk/test/ScopInfo/pointer-type-expressions.ll
    polly/trunk/test/ScopInfo/reduction_alternating_base.ll
    polly/trunk/test/ScopInfo/scalar.ll
    polly/trunk/test/ScopInfo/simple_loop_1.ll
    polly/trunk/test/ScopInfo/unsigned-condition.ll
    polly/trunk/utils/jscop2cloog.py
    polly/trunk/www/documentation/gpgpucodegen.html
    polly/trunk/www/example_manual_matmul.html
    polly/trunk/www/experiments/matmul/init_array___%for.cond---%for.end19.jscop
    polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop
    polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop.interchanged
    polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop.interchanged+tiled
    polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop.interchanged+tiled+vector

Modified: polly/trunk/include/polly/DependenceInfo.h
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/include/polly/DependenceInfo.h?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/lib/Analysis/ScopInfo.cpp (original)
+++ polly/trunk/lib/Analysis/ScopInfo.cpp Tue Apr 21 06:37:25 2015
@@ -818,45 +818,45 @@ void MemoryAccess::setNewAccessRelation(
 
 //===----------------------------------------------------------------------===//
 
-isl_map *ScopStmt::getScattering() const { return isl_map_copy(Scattering); }
+isl_map *ScopStmt::getSchedule() const { return isl_map_copy(Schedule); }
 
 void ScopStmt::restrictDomain(__isl_take isl_set *NewDomain) {
   assert(isl_set_is_subset(NewDomain, Domain) &&
          "New domain is not a subset of old domain!");
   isl_set_free(Domain);
   Domain = NewDomain;
-  Scattering = isl_map_intersect_domain(Scattering, isl_set_copy(Domain));
+  Schedule = isl_map_intersect_domain(Schedule, isl_set_copy(Domain));
 }
 
-void ScopStmt::setScattering(__isl_take isl_map *NewScattering) {
-  assert(NewScattering && "New scattering is nullptr");
-  isl_map_free(Scattering);
-  Scattering = NewScattering;
+void ScopStmt::setSchedule(__isl_take isl_map *NewSchedule) {
+  assert(NewSchedule && "New schedule is nullptr");
+  isl_map_free(Schedule);
+  Schedule = NewSchedule;
 }
 
-void ScopStmt::buildScattering(SmallVectorImpl<unsigned> &Scatter) {
+void ScopStmt::buildSchedule(SmallVectorImpl<unsigned> &ScheduleVec) {
   unsigned NbIterators = getNumIterators();
-  unsigned NbScatteringDims = Parent.getMaxLoopDepth() * 2 + 1;
+  unsigned NbScheduleDims = Parent.getMaxLoopDepth() * 2 + 1;
 
-  isl_space *Space = isl_space_set_alloc(getIslCtx(), 0, NbScatteringDims);
+  isl_space *Space = isl_space_set_alloc(getIslCtx(), 0, NbScheduleDims);
 
-  Scattering = isl_map_from_domain_and_range(isl_set_universe(getDomainSpace()),
+  Schedule = isl_map_from_domain_and_range(isl_set_universe(getDomainSpace()),
                                              isl_set_universe(Space));
 
   // Loop dimensions.
   for (unsigned i = 0; i < NbIterators; ++i)
-    Scattering =
-        isl_map_equate(Scattering, isl_dim_out, 2 * i + 1, isl_dim_in, i);
+    Schedule =
+        isl_map_equate(Schedule, isl_dim_out, 2 * i + 1, isl_dim_in, i);
 
   // Constant dimensions
   for (unsigned i = 0; i < NbIterators + 1; ++i)
-    Scattering = isl_map_fix_si(Scattering, isl_dim_out, 2 * i, Scatter[i]);
+    Schedule = isl_map_fix_si(Schedule, isl_dim_out, 2 * i, ScheduleVec[i]);
 
-  // Fill scattering dimensions.
-  for (unsigned i = 2 * NbIterators + 1; i < NbScatteringDims; ++i)
-    Scattering = isl_map_fix_si(Scattering, isl_dim_out, i, 0);
+  // Fill schedule dimensions.
+  for (unsigned i = 2 * NbIterators + 1; i < NbScheduleDims; ++i)
+    Schedule = isl_map_fix_si(Schedule, isl_dim_out, i, 0);
 
-  Scattering = isl_map_align_params(Scattering, Parent.getParamSpace());
+  Schedule = isl_map_align_params(Schedule, Parent.getParamSpace());
 }
 
 void ScopStmt::buildAccesses(TempScop &tempScop, BasicBlock *Block,
@@ -896,7 +896,7 @@ void ScopStmt::realignParams() {
     MA->realignParams();
 
   Domain = isl_set_align_params(Domain, Parent.getParamSpace());
-  Scattering = isl_map_align_params(Scattering, Parent.getParamSpace());
+  Schedule = isl_map_align_params(Schedule, Parent.getParamSpace());
 }
 
 __isl_give isl_set *ScopStmt::buildConditionSet(const Comparison &Comp) {
@@ -1056,7 +1056,7 @@ void ScopStmt::deriveAssumptions(BasicBl
 
 ScopStmt::ScopStmt(Scop &parent, TempScop &tempScop, const Region &CurRegion,
                    Region &R, SmallVectorImpl<Loop *> &Nest,
-                   SmallVectorImpl<unsigned> &Scatter)
+                   SmallVectorImpl<unsigned> &ScheduleVec)
     : Parent(parent), BB(nullptr), R(&R), Build(nullptr),
       NestLoops(Nest.size()) {
   // Setup the induction variables.
@@ -1066,7 +1066,7 @@ ScopStmt::ScopStmt(Scop &parent, TempSco
   BaseName = getIslCompatibleName("Stmt_(", R.getNameStr(), ")");
 
   Domain = buildDomain(tempScop, CurRegion);
-  buildScattering(Scatter);
+  buildSchedule(ScheduleVec);
 
   BasicBlock *EntryBB = R.getEntry();
   for (BasicBlock *Block : R.blocks()) {
@@ -1078,7 +1078,7 @@ ScopStmt::ScopStmt(Scop &parent, TempSco
 
 ScopStmt::ScopStmt(Scop &parent, TempScop &tempScop, const Region &CurRegion,
                    BasicBlock &bb, SmallVectorImpl<Loop *> &Nest,
-                   SmallVectorImpl<unsigned> &Scatter)
+                   SmallVectorImpl<unsigned> &ScheduleVec)
     : Parent(parent), BB(&bb), R(nullptr), Build(nullptr),
       NestLoops(Nest.size()) {
   // Setup the induction variables.
@@ -1088,7 +1088,7 @@ ScopStmt::ScopStmt(Scop &parent, TempSco
   BaseName = getIslCompatibleName("Stmt_", &bb, "");
 
   Domain = buildDomain(tempScop, CurRegion);
-  buildScattering(Scatter);
+  buildSchedule(ScheduleVec);
   buildAccesses(tempScop, BB);
   deriveAssumptions(BB);
   checkForReductions();
@@ -1225,16 +1225,16 @@ void ScopStmt::checkForReductions() {
 
 std::string ScopStmt::getDomainStr() const { return stringFromIslObj(Domain); }
 
-std::string ScopStmt::getScatteringStr() const {
-  return stringFromIslObj(Scattering);
+std::string ScopStmt::getScheduleStr() const {
+  return stringFromIslObj(Schedule);
 }
 
 unsigned ScopStmt::getNumParams() const { return Parent.getNumParams(); }
 
 unsigned ScopStmt::getNumIterators() const { return NestLoops.size(); }
 
-unsigned ScopStmt::getNumScattering() const {
-  return isl_map_dim(Scattering, isl_dim_out);
+unsigned ScopStmt::getNumSchedule() const {
+  return isl_map_dim(Schedule, isl_dim_out);
 }
 
 const char *ScopStmt::getBaseName() const { return BaseName.c_str(); }
@@ -1262,7 +1262,7 @@ ScopStmt::~ScopStmt() {
   }
 
   isl_set_free(Domain);
-  isl_map_free(Scattering);
+  isl_map_free(Schedule);
 }
 
 void ScopStmt::print(raw_ostream &OS) const {
@@ -1274,10 +1274,10 @@ void ScopStmt::print(raw_ostream &OS) co
   } else
     OS.indent(16) << "n/a\n";
 
-  OS.indent(12) << "Scattering :=\n";
+  OS.indent(12) << "Schedule :=\n";
 
   if (Domain) {
-    OS.indent(16) << getScatteringStr() << ";\n";
+    OS.indent(16) << getScheduleStr() << ";\n";
   } else
     OS.indent(16) << "n/a\n";
 
@@ -1680,9 +1680,9 @@ void Scop::dropConstantScheduleDims() {
   }
 
   for (auto *S : *this) {
-    isl_map *Schedule = S->getScattering();
+    isl_map *Schedule = S->getSchedule();
     Schedule = isl_map_apply_range(Schedule, isl_map_copy(DropDimMap));
-    S->setScattering(Schedule);
+    S->setSchedule(Schedule);
   }
   isl_set_free(ScheduleSpace);
   isl_map_free(DropDimMap);
@@ -1697,13 +1697,13 @@ Scop::Scop(TempScop &tempScop, LoopInfo
   buildContext();
 
   SmallVector<Loop *, 8> NestLoops;
-  SmallVector<unsigned, 8> Scatter;
+  SmallVector<unsigned, 8> Schedule;
 
-  Scatter.assign(MaxLoopDepth + 1, 0);
+  Schedule.assign(MaxLoopDepth + 1, 0);
 
-  // Build the iteration domain, access functions and scattering functions
+  // Build the iteration domain, access functions and schedule functions
   // traversing the region tree.
-  buildScop(tempScop, getRegion(), NestLoops, Scatter, LI, SD);
+  buildScop(tempScop, getRegion(), NestLoops, Schedule, LI, SD);
 
   realignParams();
   addParameterBounds();
@@ -1932,7 +1932,7 @@ __isl_give isl_union_map *Scop::getSched
   isl_union_map *Schedule = isl_union_map_empty(getParamSpace());
 
   for (ScopStmt *Stmt : *this)
-    Schedule = isl_union_map_add_map(Schedule, Stmt->getScattering());
+    Schedule = isl_union_map_add_map(Schedule, Stmt->getSchedule());
 
   return isl_union_map_coalesce(Schedule);
 }
@@ -1977,16 +1977,16 @@ bool Scop::isTrivialBB(BasicBlock *BB, T
 void Scop::addScopStmt(BasicBlock *BB, Region *R, TempScop &tempScop,
                        const Region &CurRegion,
                        SmallVectorImpl<Loop *> &NestLoops,
-                       SmallVectorImpl<unsigned> &Scatter) {
+                       SmallVectorImpl<unsigned> &ScheduleVec) {
   ScopStmt *Stmt;
 
   if (BB) {
-    Stmt = new ScopStmt(*this, tempScop, CurRegion, *BB, NestLoops, Scatter);
+    Stmt = new ScopStmt(*this, tempScop, CurRegion, *BB, NestLoops, ScheduleVec);
     StmtMap[BB] = Stmt;
   } else {
     assert(R && "Either a basic block or a region is needed to "
                 "create a new SCoP stmt.");
-    Stmt = new ScopStmt(*this, tempScop, CurRegion, *R, NestLoops, Scatter);
+    Stmt = new ScopStmt(*this, tempScop, CurRegion, *R, NestLoops, ScheduleVec);
     for (BasicBlock *BB : R->blocks())
       StmtMap[BB] = Stmt;
   }
@@ -1994,18 +1994,18 @@ void Scop::addScopStmt(BasicBlock *BB, R
   // Insert all statements into the statement map and the statement vector.
   Stmts.push_back(Stmt);
 
-  // Increasing the Scattering function is OK for the moment, because
+  // Increasing the Schedule function is OK for the moment, because
   // we are using a depth first iterator and the program is well structured.
-  ++Scatter[NestLoops.size()];
+  ++ScheduleVec[NestLoops.size()];
 }
 
 void Scop::buildScop(TempScop &tempScop, const Region &CurRegion,
                      SmallVectorImpl<Loop *> &NestLoops,
-                     SmallVectorImpl<unsigned> &Scatter, LoopInfo &LI,
+                     SmallVectorImpl<unsigned> &ScheduleVec, LoopInfo &LI,
                      ScopDetection &SD) {
   if (SD.isNonAffineSubRegion(&CurRegion, &getRegion()))
     return addScopStmt(nullptr, const_cast<Region *>(&CurRegion), tempScop,
-                       CurRegion, NestLoops, Scatter);
+                       CurRegion, NestLoops, ScheduleVec);
 
   Loop *L = castToLoop(CurRegion, LI);
 
@@ -2013,29 +2013,29 @@ void Scop::buildScop(TempScop &tempScop,
     NestLoops.push_back(L);
 
   unsigned loopDepth = NestLoops.size();
-  assert(Scatter.size() > loopDepth && "Scatter not big enough!");
+  assert(ScheduleVec.size() > loopDepth && "Schedule not big enough!");
 
   for (Region::const_element_iterator I = CurRegion.element_begin(),
                                       E = CurRegion.element_end();
        I != E; ++I)
     if (I->isSubRegion()) {
-      buildScop(tempScop, *I->getNodeAs<Region>(), NestLoops, Scatter, LI, SD);
+      buildScop(tempScop, *I->getNodeAs<Region>(), NestLoops, ScheduleVec, LI, SD);
     } else {
       BasicBlock *BB = I->getNodeAs<BasicBlock>();
 
       if (isTrivialBB(BB, tempScop))
         continue;
 
-      addScopStmt(BB, nullptr, tempScop, CurRegion, NestLoops, Scatter);
+      addScopStmt(BB, nullptr, tempScop, CurRegion, NestLoops, ScheduleVec);
     }
 
   if (!L)
     return;
 
   // Exiting a loop region.
-  Scatter[loopDepth] = 0;
+  ScheduleVec[loopDepth] = 0;
   NestLoops.pop_back();
-  ++Scatter[loopDepth - 1];
+  ++ScheduleVec[loopDepth - 1];
 }
 
 ScopStmt *Scop::getStmtForBasicBlock(BasicBlock *BB) const {

Modified: polly/trunk/lib/CodeGen/IslCodeGeneration.cpp
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/CodeGen/IslCodeGeneration.cpp?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/lib/CodeGen/IslCodeGeneration.cpp (original)
+++ polly/trunk/lib/CodeGen/IslCodeGeneration.cpp Tue Apr 21 06:37:25 2015
@@ -15,7 +15,7 @@
 // in the Scop. ISL is used to generate an abstract syntax tree that reflects
 // the updated execution order. This clast is used to create new LLVM-IR that is
 // computationally equivalent to the original control flow region, but executes
-// its code in the new execution order defined by the changed scattering.
+// its code in the new execution order defined by the changed schedule.
 //
 //===----------------------------------------------------------------------===//
 #include "polly/Config/config.h"

Modified: polly/trunk/lib/Exchange/JSONExporter.cpp
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/Exchange/JSONExporter.cpp?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/lib/Exchange/JSONExporter.cpp (original)
+++ polly/trunk/lib/Exchange/JSONExporter.cpp Tue Apr 21 06:37:25 2015
@@ -102,7 +102,7 @@ Json::Value JSONExporter::getJSON(Scop &
 
     statement["name"] = Stmt->getBaseName();
     statement["domain"] = Stmt->getDomainStr();
-    statement["schedule"] = Stmt->getScatteringStr();
+    statement["schedule"] = Stmt->getScheduleStr();
     statement["accesses"];
 
     for (MemoryAccess *MA : *Stmt) {
@@ -223,7 +223,7 @@ bool JSONImporter::runOnScop(Scop &S) {
   isl_set_free(OldContext);
   S.setContext(NewContext);
 
-  StatementToIslMapTy NewScattering;
+  StatementToIslMapTy NewSchedule;
 
   int index = 0;
 
@@ -233,19 +233,19 @@ bool JSONImporter::runOnScop(Scop &S) {
     isl_space *Space = (*SI)->getDomainSpace();
 
     // Copy the old tuple id. This is necessary to retain the user pointer,
-    // that stores the reference to the ScopStmt this scattering belongs to.
+    // that stores the reference to the ScopStmt this schedule belongs to.
     m = isl_map_set_tuple_id(m, isl_dim_in,
                              isl_space_get_tuple_id(Space, isl_dim_set));
     isl_space_free(Space);
-    NewScattering[*SI] = m;
+    NewSchedule[*SI] = m;
     index++;
   }
 
-  if (!D.isValidScattering(S, &NewScattering)) {
-    errs() << "JScop file contains a scattering that changes the "
+  if (!D.isValidSchedule(S, &NewSchedule)) {
+    errs() << "JScop file contains a schedule that changes the "
            << "dependences. Use -disable-polly-legality to continue anyways\n";
-    for (StatementToIslMapTy::iterator SI = NewScattering.begin(),
-                                       SE = NewScattering.end();
+    for (StatementToIslMapTy::iterator SI = NewSchedule.begin(),
+                                       SE = NewSchedule.end();
          SI != SE; ++SI)
       isl_map_free(SI->second);
     return false;
@@ -254,8 +254,8 @@ bool JSONImporter::runOnScop(Scop &S) {
   for (Scop::iterator SI = S.begin(), SE = S.end(); SI != SE; ++SI) {
     ScopStmt *Stmt = *SI;
 
-    if (NewScattering.find(Stmt) != NewScattering.end())
-      Stmt->setScattering(NewScattering[Stmt]);
+    if (NewSchedule.find(Stmt) != NewSchedule.end())
+      Stmt->setSchedule(NewSchedule[Stmt]);
   }
 
   int statementIdx = 0;

Modified: polly/trunk/lib/Transform/ScheduleOptimizer.cpp
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/Transform/ScheduleOptimizer.cpp?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/lib/Transform/ScheduleOptimizer.cpp (original)
+++ polly/trunk/lib/Transform/ScheduleOptimizer.cpp Tue Apr 21 06:37:25 2015
@@ -486,7 +486,7 @@ bool IslScheduleOptimizer::runOnScop(Sco
       StmtSchedule = isl_map_from_union_map(StmtBand);
     }
 
-    Stmt->setScattering(StmtSchedule);
+    Stmt->setSchedule(StmtSchedule);
   }
 
   isl_schedule_free(Schedule);

Modified: polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_1.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_1.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_1.ll (original)
+++ polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_1.ll Tue Apr 21 06:37:25 2015
@@ -13,7 +13,7 @@
 ; CHECK:      Stmt_(bb3 => bb11)
 ; CHECK:            Domain :=
 ; CHECK:                { Stmt_(bb3 => bb11)[i0] : i0 >= 0 and i0 <= 1023 };
-; CHECK:            Scattering :=
+; CHECK:            Schedule :=
 ; CHECK:                { Stmt_(bb3 => bb11)[i0] -> [i0] };
 ; CHECK:            ReadAccess := [Reduction Type: NONE] [Scalar: 0]
 ; CHECK:                { Stmt_(bb3 => bb11)[i0] -> MemRef_C[i0] };

Modified: polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_2.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_2.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_2.ll (original)
+++ polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_2.ll Tue Apr 21 06:37:25 2015
@@ -22,7 +22,7 @@
 ; INNERMOST:      Stmt_bb16
 ; INNERMOST:            Domain :=
 ; INNERMOST:                [p_0, p_1, p_2, p_3, p_4] -> { Stmt_bb16[i0] : (i0 <= 1023 - p_1 and i0 >= 0 and i0 <= 1024 + p_0) or (i0 >= 0 and i0 >= 1025 - p_1 and i0 <= 1024 + p_0) };
-; INNERMOST:            Scattering :=
+; INNERMOST:            Schedule :=
 ; INNERMOST:                [p_0, p_1, p_2, p_3, p_4] -> { Stmt_bb16[i0] -> [i0] };
 ; INNERMOST:            ReadAccess := [Reduction Type: NONE] [Scalar: 0]
 ; INNERMOST:                [p_0, p_1, p_2, p_3, p_4] -> { Stmt_bb16[i0] -> MemRef_A[o0] : 4o0 = p_2 };
@@ -47,7 +47,7 @@
 ; ALL:      Stmt_(bb15 => bb25)
 ; ALL:            Domain :=
 ; ALL:                { Stmt_(bb15 => bb25)[i0, i1] : i0 >= 0 and i0 <= 1023 and i1 >= 0 and i1 <= 1023 };
-; ALL:            Scattering :=
+; ALL:            Schedule :=
 ; ALL:                { Stmt_(bb15 => bb25)[i0, i1] -> [i0, i1] };
 ; ALL:            ReadAccess := [Reduction Type: NONE] [Scalar: 0]
 ; ALL:                { Stmt_(bb15 => bb25)[i0, i1] -> MemRef_A[i0] };

Modified: polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_3.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_3.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_3.ll (original)
+++ polly/trunk/test/ScopInfo/NonAffine/non-affine-loop-condition-dependent-access_3.ll Tue Apr 21 06:37:25 2015
@@ -24,7 +24,7 @@
 ; INNERMOST:      Stmt_bb16
 ; INNERMOST:            Domain :=
 ; INNERMOST:                [p_0, p_1, p_2] -> { Stmt_bb16[i0] : i0 >= 0 and i0 <= -1 + p_0 };
-; INNERMOST:            Scattering :=
+; INNERMOST:            Schedule :=
 ; INNERMOST:                [p_0, p_1, p_2] -> { Stmt_bb16[i0] -> [i0] };
 ; INNERMOST:            ReadAccess := [Reduction Type: NONE] [Scalar: 0]
 ; INNERMOST:                [p_0, p_1, p_2] -> { Stmt_bb16[i0] -> MemRef_A[o0] : 4o0 = p_1 };
@@ -49,7 +49,7 @@
 ; ALL:      Stmt_(bb15 => bb25)
 ; ALL:            Domain :=
 ; ALL:                { Stmt_(bb15 => bb25)[i0, i1] : i0 >= 0 and i0 <= 1023 and i1 >= 0 and i1 <= 1023 };
-; ALL:            Scattering :=
+; ALL:            Schedule :=
 ; ALL:                { Stmt_(bb15 => bb25)[i0, i1] -> [i0, i1] };
 ; ALL:            ReadAccess := [Reduction Type: NONE] [Scalar: 0]
 ; ALL:                { Stmt_(bb15 => bb25)[i0, i1] -> MemRef_A[i0] };

Modified: polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_nested.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_nested.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_nested.ll (original)
+++ polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_nested.ll Tue Apr 21 06:37:25 2015
@@ -13,7 +13,7 @@
 ; CHECK:      Stmt_(bb2 => bb16)
 ; CHECK:            Domain :=
 ; CHECK:                { Stmt_(bb2 => bb16)[i0] : i0 >= 0 and i0 <= 1023 };
-; CHECK:            Scattering :=
+; CHECK:            Schedule :=
 ; CHECK:                { Stmt_(bb2 => bb16)[i0] -> [i0] };
 ; CHECK:            ReadAccess := [Reduction Type: NONE] [Scalar: 0]
 ; CHECK:                { Stmt_(bb2 => bb16)[i0] -> MemRef_A[i0] };

Modified: polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_surrounding_affine_loop.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_surrounding_affine_loop.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_surrounding_affine_loop.ll (original)
+++ polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_surrounding_affine_loop.ll Tue Apr 21 06:37:25 2015
@@ -15,7 +15,7 @@
 ; INNERMOST:      Stmt_bb11
 ; INNERMOST:            Domain :=
 ; INNERMOST:                [N] -> { Stmt_bb11[i0] : i0 >= 0 and N >= 1 and i0 <= -1 + N };
-; INNERMOST:            Scattering :=
+; INNERMOST:            Schedule :=
 ; INNERMOST:                [N] -> { Stmt_bb11[i0] -> [i0] };
 ; INNERMOST:            ReadAccess := [Reduction Type: +] [Scalar: 0]
 ; INNERMOST:                [N] -> { Stmt_bb11[i0] -> MemRef_A[i0] };
@@ -36,7 +36,7 @@
 ; ALL:      Stmt_(bb4 => bb17)
 ; ALL:            Domain :=
 ; ALL:                { Stmt_(bb4 => bb17)[i0] : i0 >= 0 and i0 <= 1023 };
-; ALL:            Scattering :=
+; ALL:            Schedule :=
 ; ALL:                { Stmt_(bb4 => bb17)[i0] -> [i0] };
 ; ALL:            ReadAccess := [Reduction Type: NONE] [Scalar: 0]
 ; ALL:                { Stmt_(bb4 => bb17)[i0] -> MemRef_A[i0] };

Modified: polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_surrounding_non_affine_loop.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_surrounding_non_affine_loop.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_surrounding_non_affine_loop.ll (original)
+++ polly/trunk/test/ScopInfo/NonAffine/non_affine_conditional_surrounding_non_affine_loop.ll Tue Apr 21 06:37:25 2015
@@ -15,7 +15,7 @@
 ; INNERMOST:      Stmt_bb12
 ; INNERMOST:            Domain :=
 ; INNERMOST:                [p_0] -> { Stmt_bb12[i0] : i0 >= 0 and p_0 >= 1 and i0 <= -1 + p_0 };
-; INNERMOST:            Scattering :=
+; INNERMOST:            Schedule :=
 ; INNERMOST:                [p_0] -> { Stmt_bb12[i0] -> [i0] };
 ; INNERMOST:            ReadAccess := [Reduction Type: +] [Scalar: 0]
 ; INNERMOST:                [p_0] -> { Stmt_bb12[i0] -> MemRef_A[i0] };
@@ -36,7 +36,7 @@
 ; ALL:      Stmt_(bb4 => bb18)
 ; ALL:            Domain :=
 ; ALL:                { Stmt_(bb4 => bb18)[i0] : i0 >= 0 and i0 <= 1023 };
-; ALL:            Scattering :=
+; ALL:            Schedule :=
 ; ALL:                { Stmt_(bb4 => bb18)[i0] -> [i0] };
 ; ALL:            ReadAccess := [Reduction Type: NONE] [Scalar: 0]
 ; ALL:                { Stmt_(bb4 => bb18)[i0] -> MemRef_A[i0] };

Modified: polly/trunk/test/ScopInfo/NonAffine/non_affine_float_compare.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/NonAffine/non_affine_float_compare.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/NonAffine/non_affine_float_compare.ll (original)
+++ polly/trunk/test/ScopInfo/NonAffine/non_affine_float_compare.ll Tue Apr 21 06:37:25 2015
@@ -13,7 +13,7 @@
 ; CHECK:      Stmt_(bb2 => bb12)
 ; CHECK:            Domain :=
 ; CHECK:                { Stmt_(bb2 => bb12)[i0] : i0 >= 0 and i0 <= 1023 };
-; CHECK:            Scattering :=
+; CHECK:            Schedule :=
 ; CHECK:                { Stmt_(bb2 => bb12)[i0] -> [i0] };
 ; CHECK:            ReadAccess := [Reduction Type: NONE] [Scalar: 0]
 ; CHECK:                { Stmt_(bb2 => bb12)[i0] -> MemRef_A[i0] };

Modified: polly/trunk/test/ScopInfo/NonAffine/non_affine_loop_condition.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/NonAffine/non_affine_loop_condition.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/NonAffine/non_affine_loop_condition.ll (original)
+++ polly/trunk/test/ScopInfo/NonAffine/non_affine_loop_condition.ll Tue Apr 21 06:37:25 2015
@@ -14,7 +14,7 @@
 ; CHECK:      Stmt_(bb3 => bb10)
 ; CHECK:            Domain :=
 ; CHECK:                { Stmt_(bb3 => bb10)[i0] : i0 >= 0 and i0 <= 1023 };
-; CHECK:            Scattering :=
+; CHECK:            Schedule :=
 ; CHECK:                { Stmt_(bb3 => bb10)[i0] -> [i0] };
 ; CHECK:            ReadAccess := [Reduction Type: NONE] [Scalar: 0]
 ; CHECK:                { Stmt_(bb3 => bb10)[i0] -> MemRef_C[i0] };

Modified: polly/trunk/test/ScopInfo/NonAffine/non_affine_loop_used_later.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/NonAffine/non_affine_loop_used_later.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/NonAffine/non_affine_loop_used_later.ll (original)
+++ polly/trunk/test/ScopInfo/NonAffine/non_affine_loop_used_later.ll Tue Apr 21 06:37:25 2015
@@ -17,7 +17,7 @@
 ; CHECK:      Stmt_bb2
 ; CHECK:            Domain :=
 ; CHECK:                [N] -> { Stmt_bb2[i0] : i0 >= 0 and N >= 1 and i0 <= N; Stmt_bb2[0] : N <= 0 };
-; CHECK:            Scattering :=
+; CHECK:            Schedule :=
 ; CHECK:                [N] -> { Stmt_bb2[i0] -> [i0, 0] };
 ; CHECK:            ReadAccess := [Reduction Type: NONE] [Scalar: 1]
 ; CHECK:                [N] -> { Stmt_bb2[i0] -> MemRef_j_0[] };
@@ -26,7 +26,7 @@
 ; CHECK:      Stmt_(bb4 => bb18)
 ; CHECK:            Domain :=
 ; CHECK:                [N] -> { Stmt_(bb4 => bb18)[i0] : i0 >= 0 and N >= 1 and i0 <= -1 + N };
-; CHECK:            Scattering :=
+; CHECK:            Schedule :=
 ; CHECK:                [N] -> { Stmt_(bb4 => bb18)[i0] -> [i0, 1] };
 ; CHECK:            ReadAccess := [Reduction Type: NONE] [Scalar: 0]
 ; CHECK:                [N] -> { Stmt_(bb4 => bb18)[i0] -> MemRef_A[i0] };
@@ -45,7 +45,7 @@
 ; CHECK:      Stmt_bb18
 ; CHECK:            Domain :=
 ; CHECK:                [N] -> { Stmt_bb18[i0] : i0 >= 0 and N >= 1 and i0 <= -1 + N };
-; CHECK:            Scattering :=
+; CHECK:            Schedule :=
 ; CHECK:                [N] -> { Stmt_bb18[i0] -> [i0, 2] };
 ; CHECK:            MustWriteAccess :=  [Reduction Type: NONE] [Scalar: 1]
 ; CHECK:                [N] -> { Stmt_bb18[i0] -> MemRef_j_2[] };
@@ -58,7 +58,7 @@
 ; CHECK:      Stmt_bb23
 ; CHECK:            Domain :=
 ; CHECK:                [N] -> { Stmt_bb23[i0] : i0 >= 0 and N >= 1 and i0 <= -1 + N };
-; CHECK:            Scattering :=
+; CHECK:            Schedule :=
 ; CHECK:                [N] -> { Stmt_bb23[i0] -> [i0, 3] };
 ; CHECK:            ReadAccess := [Reduction Type: NONE] [Scalar: 1]
 ; CHECK:                [N] -> { Stmt_bb23[i0] -> MemRef_j_2[] };

Modified: polly/trunk/test/ScopInfo/NonAffine/non_affine_parametric_loop.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/NonAffine/non_affine_parametric_loop.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/NonAffine/non_affine_parametric_loop.ll (original)
+++ polly/trunk/test/ScopInfo/NonAffine/non_affine_parametric_loop.ll Tue Apr 21 06:37:25 2015
@@ -29,7 +29,7 @@ for.end:
 
 ; CHECK: Domain
 ; CHECK:   [n] -> { Stmt_for_body[i0] : i0 >= 0 and i0 <= -1 + n };
-; CHECK: Scattering
+; CHECK: Schedule
 ; CHECK:   [n] -> { Stmt_for_body[i0] -> [i0] };
 ; CHECK: ReadAccess
 ; CHECK:   [n] -> { Stmt_for_body[i0] -> MemRef_INDEX[i0] };

Modified: polly/trunk/test/ScopInfo/loop_affine_bound_0.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/loop_affine_bound_0.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/loop_affine_bound_0.ll (original)
+++ polly/trunk/test/ScopInfo/loop_affine_bound_0.ll Tue Apr 21 06:37:25 2015
@@ -57,7 +57,7 @@ return:
 ; CHECK:    Stmt_bb1
 ; CHECK:          Domain :=
 ; CHECK:              [N, M] -> { Stmt_bb1[i0, i1] : i0 >= 0 and i0 <= 2 + 4N + 7M and i1 >= 0 and i1 <= 1 + 5N and N >= 0 };
-; CHECK:          Scattering :=
+; CHECK:          Schedule :=
 ; CHECK:              [N, M] -> { Stmt_bb1[i0, i1] -> [i0, i1] };
 ; CHECK:          MustWriteAccess := [Reduction Type: NONE]
 ; CHECK:              [N, M] -> { Stmt_bb1[i0, i1] -> MemRef_a[i0 + 128i1] };

Modified: polly/trunk/test/ScopInfo/loop_affine_bound_1.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/loop_affine_bound_1.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/loop_affine_bound_1.ll (original)
+++ polly/trunk/test/ScopInfo/loop_affine_bound_1.ll Tue Apr 21 06:37:25 2015
@@ -56,7 +56,7 @@ return:
 ; CHECK:   Stmt_bb1
 ; CHECK:         Domain :=
 ; CHECK:             [N, M] -> { Stmt_bb1[i0, i1] : i0 >= 0 and i0 <= 2 + 4N + 7M and i1 >= 0 and i1 <= 1 + 5N - i0 and i0 <= 1 + 5N };
-; CHECK:         Scattering :=
+; CHECK:         Schedule :=
 ; CHECK:             [N, M] -> { Stmt_bb1[i0, i1] -> [i0, i1] };
 ; CHECK:         MustWriteAccess := [Reduction Type: NONE]
 ; CHECK:             [N, M] -> { Stmt_bb1[i0, i1] -> MemRef_a[129i0 + 128i1] };

Modified: polly/trunk/test/ScopInfo/loop_affine_bound_2.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/loop_affine_bound_2.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/loop_affine_bound_2.ll (original)
+++ polly/trunk/test/ScopInfo/loop_affine_bound_2.ll Tue Apr 21 06:37:25 2015
@@ -67,7 +67,7 @@ return:
 ; CHECK:   Stmt_bb1
 ; CHECK:         Domain :=
 ; CHECK:             [N, M] -> { Stmt_bb1[i0, i1] : i0 >= 0 and i0 <= 2 + 4N + 7M and i1 >= 0 and i1 <= 10 + 5N - 6M - 4i0 and 4i0 <= 10 + 5N - 6M };
-; CHECK:         Scattering :=
+; CHECK:         Schedule :=
 ; CHECK:             [N, M] -> { Stmt_bb1[i0, i1] -> [i0, i1] };
 ; CHECK:         MustWriteAccess := [Reduction Type: NONE]
 ; CHECK:             [N, M] -> { Stmt_bb1[i0, i1] -> MemRef_a[-1152 + 768M + 897i0 + 128i1] };

Modified: polly/trunk/test/ScopInfo/loop_carry.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/loop_carry.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/loop_carry.ll (original)
+++ polly/trunk/test/ScopInfo/loop_carry.ll Tue Apr 21 06:37:25 2015
@@ -52,7 +52,7 @@ bb2:
 ; CHECK:     	Stmt_bb_nph
 ; CHECK:             Domain :=
 ; CHECK:                 [n] -> { Stmt_bb_nph[] : n >= 2 };
-; CHECK:             Scattering :=
+; CHECK:             Schedule :=
 ; CHECK:                 [n] -> { Stmt_bb_nph[] -> [0, 0] };
 ; CHECK:             ReadAccess :=
 ; CHECK:                 [n] -> { Stmt_bb_nph[] -> MemRef_a[0] };
@@ -63,7 +63,7 @@ bb2:
 ; CHECK:     	Stmt_bb
 ; CHECK:             Domain :=
 ; CHECK:                 [n] -> { Stmt_bb[i0] : i0 >= 0 and i0 <= -2 + n and n >= 2 };
-; CHECK:             Scattering :=
+; CHECK:             Schedule :=
 ; CHECK:                 [n] -> { Stmt_bb[i0] -> [1, i0] };
 ; CHECK:             ReadAccess :=
 ; CHECK:                 [n] -> { Stmt_bb[i0] -> MemRef__reg2mem[0] };

Modified: polly/trunk/test/ScopInfo/multidim_2d-diagonal-matrix.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/multidim_2d-diagonal-matrix.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/multidim_2d-diagonal-matrix.ll (original)
+++ polly/trunk/test/ScopInfo/multidim_2d-diagonal-matrix.ll Tue Apr 21 06:37:25 2015
@@ -18,7 +18,7 @@ target triple = "x86_64-unknown-linux-gn
 
 ; CHECK: Domain :=
 ; CHECK:   [n] -> { Stmt_for_i[i0] : i0 >= 0 and i0 <= -1 + n };
-; CHECK: Scattering :=
+; CHECK: Schedule :=
 ; CHECK:   [n] -> { Stmt_for_i[i0] -> [i0] };
 ; CHECK: MustWriteAccess :=
 ; CHECK:   [n] -> { Stmt_for_i[i0] -> MemRef_A[i0, i0] };

Modified: polly/trunk/test/ScopInfo/multidim_2d_outer_parametric_offset.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/multidim_2d_outer_parametric_offset.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/multidim_2d_outer_parametric_offset.ll (original)
+++ polly/trunk/test/ScopInfo/multidim_2d_outer_parametric_offset.ll Tue Apr 21 06:37:25 2015
@@ -18,7 +18,7 @@ target triple = "x86_64-unknown-linux-gn
 ; CHECK:    Stmt_for_j
 ; CHECK:          Domain :=
 ; CHECK:              [m, p] -> { Stmt_for_j[i0, i1] : i0 >= 0 and i0 <= 99 and i1 >= 0 and i1 <= -1 + m };
-; CHECK:          Scattering :=
+; CHECK:          Schedule :=
 ; CHECK:              [m, p] -> { Stmt_for_j[i0, i1] -> [i0, i1] };
 ; CHECK:          MustWriteAccess := [Reduction Type: NONE]
 ; CHECK:              [m, p] -> { Stmt_for_j[i0, i1] -> MemRef_A[p + i0, i1] };

Modified: polly/trunk/test/ScopInfo/multidim_2d_parametric_array_static_loop_bounds.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/multidim_2d_parametric_array_static_loop_bounds.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/multidim_2d_parametric_array_static_loop_bounds.ll (original)
+++ polly/trunk/test/ScopInfo/multidim_2d_parametric_array_static_loop_bounds.ll Tue Apr 21 06:37:25 2015
@@ -16,7 +16,7 @@ target triple = "x86_64-unknown-linux-gn
 ; CHECK:   Stmt_for_j
 ; CHECK:         Domain :=
 ; CHECK:             [m] -> { Stmt_for_j[i0, i1] : i0 >= 0 and i0 <= 99 and i1 >= 0 and i1 <= 149 };
-; CHECK:         Scattering :=
+; CHECK:         Schedule :=
 ; CHECK:             [m] -> { Stmt_for_j[i0, i1] -> [i0, i1] };
 ; CHECK:         MustWriteAccess := [Reduction Type: NONE]
 ; CHECK:             [m] -> { Stmt_for_j[i0, i1] -> MemRef_A[i0, i1] };

Modified: polly/trunk/test/ScopInfo/multidim_3d_parametric_array_static_loop_bounds.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/multidim_3d_parametric_array_static_loop_bounds.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/multidim_3d_parametric_array_static_loop_bounds.ll (original)
+++ polly/trunk/test/ScopInfo/multidim_3d_parametric_array_static_loop_bounds.ll Tue Apr 21 06:37:25 2015
@@ -18,7 +18,7 @@ target triple = "x86_64-unknown-linux-gn
 ; CHECK:     Stmt_for_k
 ; CHECK:           Domain :=
 ; CHECK:               [o, m] -> { Stmt_for_k[i0, i1, i2] : i0 >= 0 and i0 <= 99 and i1 >= 0 and i1 <= 149 and i2 >= 0 and i2 <= 199 };
-; CHECK:           Scattering :=
+; CHECK:           Schedule :=
 ; CHECK:               [o, m] -> { Stmt_for_k[i0, i1, i2] -> [i0, i1, i2] };
 ; CHECK:           MustWriteAccess := [Reduction Type: NONE]
 ; CHECK:               [o, m] -> { Stmt_for_k[i0, i1, i2] -> MemRef_A[i0, i1, i2] };

Modified: polly/trunk/test/ScopInfo/multidim_ivs_and_integer_offsets_3d.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/multidim_ivs_and_integer_offsets_3d.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/multidim_ivs_and_integer_offsets_3d.ll (original)
+++ polly/trunk/test/ScopInfo/multidim_ivs_and_integer_offsets_3d.ll Tue Apr 21 06:37:25 2015
@@ -20,7 +20,7 @@ target triple = "x86_64-unknown-linux-gn
 
 ; CHECK: Domain
 ; CHECK:   [n, m, o] -> { Stmt_for_k[i0, i1, i2] : i0 >= 0 and i0 <= -4 + n and i1 >= 0 and i1 <= -5 + m and i2 >= 0 and i2 <= -8 + o };
-; CHECK: Scattering
+; CHECK: Schedule
 ; CHECK:   [n, m, o] -> { Stmt_for_k[i0, i1, i2] -> [i0, i1, i2] };
 ; CHECK: MustWriteAccess
 ; CHECK:   [n, m, o] -> { Stmt_for_k[i0, i1, i2] -> MemRef_A[3 + i0, i1, 7 + i2] };

Modified: polly/trunk/test/ScopInfo/multidim_ivs_and_parameteric_offsets_3d.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/multidim_ivs_and_parameteric_offsets_3d.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/multidim_ivs_and_parameteric_offsets_3d.ll (original)
+++ polly/trunk/test/ScopInfo/multidim_ivs_and_parameteric_offsets_3d.ll Tue Apr 21 06:37:25 2015
@@ -27,7 +27,7 @@ target triple = "x86_64-unknown-linux-gn
 ;
 ; CHECK: Domain
 ; CHECK:   [n, m, o, p, q, r] -> { Stmt_for_k[i0, i1, i2] : i0 >= 0 and i0 <= -1 + n and i1 >= 0 and i1 <= -1 + m and i2 >= 0 and i2 <= -1 + o };
-; CHECK: Scattering
+; CHECK: Schedule
 ; CHECK:   [n, m, o, p, q, r] -> { Stmt_for_k[i0, i1, i2] -> [i0, i1, i2] };
 ; CHECK: MustWriteAccess
 ; CHECK: [n, m, o, p, q, r] -> { Stmt_for_k[i0, i1, i2] -> MemRef_A[-1 + p + i0, -1 + m + q + i1, o + r + i2] : i1 <= -q and i2 <= -1 - r; Stmt_for_k[i0, i1, i2] -> MemRef_A[p + i0, -1 + q + i1, o + r + i2] : i1 >= 1 - q and i2 <= -1 - r; Stmt_for_k[i0, i1, i2] -> MemRef_A[-1 + p + i0, m + q + i1, r + i2] : i1 <= -1 - q and i2 >= -r; Stmt_for_k[i0, i1, i2] -> MemRef_A[p + i0, q + i1, r + i2] : i1 >= -q and i2 >= -r };

Modified: polly/trunk/test/ScopInfo/multidim_nested_start_integer.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/multidim_nested_start_integer.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/multidim_nested_start_integer.ll (original)
+++ polly/trunk/test/ScopInfo/multidim_nested_start_integer.ll Tue Apr 21 06:37:25 2015
@@ -17,7 +17,7 @@ target triple = "x86_64-unknown-linux-gn
 ; CHECK-NOT: p3
 ; CHECK: Domain
 ; CHECK:   [n, m, o] -> { Stmt_for_k[i0, i1, i2] : i0 >= 0 and i0 <= -4 + n and i1 >= 0 and i1 <= -5 + m and i2 >= 0 and i2 <= -8 + o };
-; CHECK: Scattering
+; CHECK: Schedule
 ; CHECK:   [n, m, o] -> { Stmt_for_k[i0, i1, i2] -> [i0, i1, i2] };
 ; CHECK: MustWriteAccess
 ; CHECK:   [n, m, o] -> { Stmt_for_k[i0, i1, i2] -> MemRef_A[3 + i0, i1, 7 + i2] };

Modified: polly/trunk/test/ScopInfo/multidim_only_ivs_2d.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/multidim_only_ivs_2d.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/multidim_only_ivs_2d.ll (original)
+++ polly/trunk/test/ScopInfo/multidim_only_ivs_2d.ll Tue Apr 21 06:37:25 2015
@@ -18,7 +18,7 @@ target triple = "x86_64-unknown-linux-gn
 
 ; CHECK: Domain
 ; CHECK:   [n, m] -> { Stmt_for_j[i0, i1] : i0 >= 0 and i0 <= -1 + n and i1 >= 0 and i1 <= -1 + m };
-; CHECK: Scattering
+; CHECK: Schedule
 ; CHECK:   [n, m] -> { Stmt_for_j[i0, i1] -> [i0, i1] };
 ; CHECK: MustWriteAccess
 ; CHECK:   [n, m] -> { Stmt_for_j[i0, i1] -> MemRef_A[i0, i1] };

Modified: polly/trunk/test/ScopInfo/multidim_only_ivs_3d.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/multidim_only_ivs_3d.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/multidim_only_ivs_3d.ll (original)
+++ polly/trunk/test/ScopInfo/multidim_only_ivs_3d.ll Tue Apr 21 06:37:25 2015
@@ -19,7 +19,7 @@ target triple = "x86_64-unknown-linux-gn
 ;
 ; CHECK: Domain
 ; CHECK:   [n, m, o] -> { Stmt_for_k[i0, i1, i2] : i0 >= 0 and i0 <= -1 + n and i1 >= 0 and i1 <= -1 + m and i2 >= 0 and i2 <= -1 + o };
-; CHECK: Scattering
+; CHECK: Schedule
 ; CHECK:   [n, m, o] -> { Stmt_for_k[i0, i1, i2] -> [i0, i1, i2] };
 ; CHECK: WriteAccess
 ; CHECK:   [n, m, o] -> { Stmt_for_k[i0, i1, i2] -> MemRef_A[i0, i1, i2] };

Modified: polly/trunk/test/ScopInfo/multidim_only_ivs_3d_cast.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/multidim_only_ivs_3d_cast.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/multidim_only_ivs_3d_cast.ll (original)
+++ polly/trunk/test/ScopInfo/multidim_only_ivs_3d_cast.ll Tue Apr 21 06:37:25 2015
@@ -26,7 +26,7 @@
 
 ; CHECK: Domain
 ; CHECK:   [n, m, o, p_3, p_4] -> { Stmt_for_k[i0, i1, i2] : i0 >= 0 and i0 <= -1 + n and i1 >= 0 and i1 <= -1 + m and i2 >= 0 and i2 <= -1 + o };
-; CHECK: Scattering
+; CHECK: Schedule
 ; CHECK:   [n, m, o, p_3, p_4] -> { Stmt_for_k[i0, i1, i2] -> [i0, i1, i2] };
 ; CHECK: WriteAccess
 ; CHECK:   [n, m, o, p_3, p_4] -> { Stmt_for_k[i0, i1, i2] -> MemRef_A[i0, i1, i2] };

Modified: polly/trunk/test/ScopInfo/multidim_only_ivs_3d_reverse.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/multidim_only_ivs_3d_reverse.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/multidim_only_ivs_3d_reverse.ll (original)
+++ polly/trunk/test/ScopInfo/multidim_only_ivs_3d_reverse.ll Tue Apr 21 06:37:25 2015
@@ -24,7 +24,7 @@ target triple = "x86_64-unknown-linux-gn
 ;
 ; CHECK: Domain
 ; CHECK:  [n, o, m] -> { Stmt_for_j[i0, i1, i2] : i0 >= 0 and i0 <= -1 + n and i1 >= 0 and i1 <= -1 + o and i2 >= 0 and i2 <= -1 + m };
-; CHECK: Scattering
+; CHECK: Schedule
 ; CHECK:   [n, o, m] -> { Stmt_for_j[i0, i1, i2] -> [i0, i1, i2] };
 ; CHECK: WriteAccess
 ; CHECK:   [n, o, m] -> { Stmt_for_j[i0, i1, i2] -> MemRef_A[i0, i2, i1] };

Modified: polly/trunk/test/ScopInfo/non_affine_region_1.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/non_affine_region_1.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/non_affine_region_1.ll (original)
+++ polly/trunk/test/ScopInfo/non_affine_region_1.ll Tue Apr 21 06:37:25 2015
@@ -31,7 +31,7 @@
 ; CHECK:       Stmt_(bb10 => bb18)
 ; CHECK-NEXT:        Domain :=
 ; CHECK-NEXT:            [b] -> { Stmt_(bb10 => bb18)[i0] : i0 >= 0 and i0 <= 1023 };
-; CHECK-NEXT:        Scattering :=
+; CHECK-NEXT:        Schedule :=
 ; CHECK-NEXT:            [b] -> { Stmt_(bb10 => bb18)[i0] -> [i0, 3] };
 ; CHECK-NEXT:        ReadAccess := [Reduction Type: NONE] [Scalar: 1]
 ; CHECK-NEXT:            [b] -> { Stmt_(bb10 => bb18)[i0] -> MemRef_x_1[] }

Modified: polly/trunk/test/ScopInfo/non_affine_region_2.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/non_affine_region_2.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/non_affine_region_2.ll (original)
+++ polly/trunk/test/ScopInfo/non_affine_region_2.ll Tue Apr 21 06:37:25 2015
@@ -23,7 +23,7 @@
 ; CHECK:   Stmt_(bb3 => bb18)
 ; CHECK:         Domain :=
 ; CHECK:             { Stmt_(bb3 => bb18)[i0] : i0 >= 0 and i0 <= 1023 };
-; CHECK:         Scattering :=
+; CHECK:         Schedule :=
 ; CHECK:             { Stmt_(bb3 => bb18)[i0] -> [i0, 0] };
 ; CHECK-NOT:         { Stmt_(bb3 => bb18)[i0] -> MemRef_x_0[] };
 ; CHECK-NOT:         { Stmt_(bb3 => bb18)[i0] -> MemRef_x_1[] };
@@ -42,7 +42,7 @@
 ; CHECK:   Stmt_bb18
 ; CHECK:         Domain :=
 ; CHECK:             { Stmt_bb18[i0] : i0 >= 0 and i0 <= 1023 };
-; CHECK:         Scattering :=
+; CHECK:         Schedule :=
 ; CHECK:             { Stmt_bb18[i0] -> [i0, 1] };
 ; CHECK:         ReadAccess := [Reduction Type: NONE] [Scalar: 1]
 ; CHECK:             { Stmt_bb18[i0] -> MemRef_x_2[] };

Modified: polly/trunk/test/ScopInfo/non_affine_region_3.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/non_affine_region_3.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/non_affine_region_3.ll (original)
+++ polly/trunk/test/ScopInfo/non_affine_region_3.ll Tue Apr 21 06:37:25 2015
@@ -23,7 +23,7 @@
 ; CHECK:   Stmt_(bb3 => bb18)
 ; CHECK:         Domain :=
 ; CHECK:             { Stmt_(bb3 => bb18)[i0] : i0 >= 0 and i0 <= 1023 };
-; CHECK:         Scattering :=
+; CHECK:         Schedule :=
 ; CHECK:             { Stmt_(bb3 => bb18)[i0] -> [i0, 0] };
 ; CHECK:         ReadAccess := [Reduction Type: NONE] [Scalar: 0]
 ; CHECK:             { Stmt_(bb3 => bb18)[i0] -> MemRef_A[i0] };
@@ -38,7 +38,7 @@
 ; CHECK:   Stmt_bb18
 ; CHECK:         Domain :=
 ; CHECK:             { Stmt_bb18[i0] : i0 >= 0 and i0 <= 1023 };
-; CHECK:         Scattering :=
+; CHECK:         Schedule :=
 ; CHECK:             { Stmt_bb18[i0] -> [i0, 1] };
 ; CHECK:         ReadAccess := [Reduction Type: NONE] [Scalar: 1]
 ; CHECK:             { Stmt_bb18[i0] -> MemRef_x_2[] };

Modified: polly/trunk/test/ScopInfo/non_affine_region_4.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/non_affine_region_4.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/non_affine_region_4.ll (original)
+++ polly/trunk/test/ScopInfo/non_affine_region_4.ll Tue Apr 21 06:37:25 2015
@@ -16,7 +16,7 @@
 ; CHECK:      Stmt_(bb2 => bb7)
 ; CHECK:            Domain :=
 ; CHECK:                { Stmt_(bb2 => bb7)[i0] : i0 >= 0 and i0 <= 1023 };
-; CHECK:            Scattering :=
+; CHECK:            Schedule :=
 ; CHECK:                { Stmt_(bb2 => bb7)[i0] -> [i0, 0] };
 ; CHECK:            ReadAccess := [Reduction Type: NONE] [Scalar: 0]
 ; CHECK:                { Stmt_(bb2 => bb7)[i0] -> MemRef_A[i0] };
@@ -29,7 +29,7 @@
 ; CHECK:      Stmt_bb7
 ; CHECK:            Domain :=
 ; CHECK:                { Stmt_bb7[i0] : i0 >= 0 and i0 <= 1023 };
-; CHECK:            Scattering :=
+; CHECK:            Schedule :=
 ; CHECK:                { Stmt_bb7[i0] -> [i0, 1] };
 ; CHECK:            ReadAccess := [Reduction Type: NONE] [Scalar: 1]
 ; CHECK:                { Stmt_bb7[i0] -> MemRef_x[] };

Modified: polly/trunk/test/ScopInfo/pointer-type-expressions.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/pointer-type-expressions.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/pointer-type-expressions.ll (original)
+++ polly/trunk/test/ScopInfo/pointer-type-expressions.ll Tue Apr 21 06:37:25 2015
@@ -43,7 +43,7 @@ return:
 ; CHECK:                or
 ; CHECK:              (P >= 1 and i0 >= 0 and i0 <= -1 + N)
 ; CHECK:                   };
-; CHECK:        Scattering :=
+; CHECK:        Schedule :=
 ; CHECK:            [N, P] -> { Stmt_store[i0] -> [i0] };
 ; CHECK:        MustWriteAccess := [Reduction Type: NONE]
 ; CHECK:            [N, P] -> { Stmt_store[i0] -> MemRef_a[i0] };

Modified: polly/trunk/test/ScopInfo/reduction_alternating_base.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/reduction_alternating_base.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/reduction_alternating_base.ll (original)
+++ polly/trunk/test/ScopInfo/reduction_alternating_base.ll Tue Apr 21 06:37:25 2015
@@ -3,7 +3,7 @@
 ; FIXME: We cannot detect this SCoP yet but as soon as we can we should check
 ;        that the reduction is detected!
 ;
-; CHECK-NOT: Scattering
+; CHECK-NOT: Schedule
 ;
 ;    void f(int *A) {
 ;      for (int i = 0; i < 1024; i++)

Modified: polly/trunk/test/ScopInfo/scalar.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/scalar.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/scalar.ll (original)
+++ polly/trunk/test/ScopInfo/scalar.ll Tue Apr 21 06:37:25 2015
@@ -33,7 +33,7 @@ return:
 ; CHECK: Stmt_S1
 ; CHECK:       Domain :=
 ; CHECK:           [N] -> { Stmt_S1[i0] : i0 >= 0 and i0 <= -1 + N };
-; CHECK:       Scattering :=
+; CHECK:       Schedule :=
 ; CHECK:           [N] -> { Stmt_S1[i0] -> [i0, 0] };
 ; CHECK:       ReadAccess :=
 ; CHECK:           [N] -> { Stmt_S1[i0] -> MemRef_a[i0] };
@@ -42,7 +42,7 @@ return:
 ; CHECK: Stmt_S2
 ; CHECK:       Domain :=
 ; CHECK:           [N] -> { Stmt_S2[i0] : i0 >= 0 and i0 <= -1 + N };
-; CHECK:       Scattering :=
+; CHECK:       Schedule :=
 ; CHECK:           [N] -> { Stmt_S2[i0] -> [i0, 1] };
 ; CHECK:       ReadAccess :=
 ; CHECK:           [N] -> { Stmt_S2[i0] -> MemRef_val[] };

Modified: polly/trunk/test/ScopInfo/simple_loop_1.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/simple_loop_1.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/simple_loop_1.ll (original)
+++ polly/trunk/test/ScopInfo/simple_loop_1.ll Tue Apr 21 06:37:25 2015
@@ -31,7 +31,7 @@ return:
 ; CHECK:  Stmt_bb
 ; CHECK:        Domain :=
 ; CHECK:            [N] -> { Stmt_bb[i0] : i0 >= 0 and i0 <= -1 + N };
-; CHECK:        Scattering :=
+; CHECK:        Schedule :=
 ; CHECK:            [N] -> { Stmt_bb[i0] -> [i0] };
 ; CHECK:        MustWriteAccess := [Reduction Type: NONE]
 ; CHECK:            [N] -> { Stmt_bb[i0] -> MemRef_a[i0] };

Modified: polly/trunk/test/ScopInfo/unsigned-condition.ll
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/test/ScopInfo/unsigned-condition.ll?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/test/ScopInfo/unsigned-condition.ll (original)
+++ polly/trunk/test/ScopInfo/unsigned-condition.ll Tue Apr 21 06:37:25 2015
@@ -41,7 +41,7 @@ return:
 ; CHECK:            [N, P] -> { Stmt_store[i0] :
 ; CHECK:              i0 >= 0 and i0 <= -1 + N and P >= 42
 ; CHECK:                   };
-; CHECK:        Scattering :=
+; CHECK:        Schedule :=
 ; CHECK:            [N, P] -> { Stmt_store[i0] -> [i0] };
 ; CHECK:        MustWriteAccess := [Reduction Type: NONE]
 ; CHECK:            [N, P] -> { Stmt_store[i0] -> MemRef_a[i0] };

Modified: polly/trunk/utils/jscop2cloog.py
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/utils/jscop2cloog.py?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/utils/jscop2cloog.py (original)
+++ polly/trunk/utils/jscop2cloog.py Tue Apr 21 06:37:25 2015
@@ -44,7 +44,7 @@ c # language is C
 # --------------------- SCATTERING --------------------
 %s
 
-0 # We do not want to set manually the scattering dimension names
+0 # We do not want to set manually the schedule dimension names
 """
 
   context = scop['context']

Modified: polly/trunk/www/documentation/gpgpucodegen.html
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/www/documentation/gpgpucodegen.html?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/www/documentation/gpgpucodegen.html (original)
+++ polly/trunk/www/documentation/gpgpucodegen.html Tue Apr 21 06:37:25 2015
@@ -110,11 +110,11 @@ for(i = 0; i < 128; i++)
    tiled code.</p>
 The "schedule" part of the pre-optimization jscop file is as the following:
 <pre>
-"schedule" : "{ Stmt_for_body3[i0, i1] -> scattering[0, i0, 0, i1, 0] }"
+"schedule" : "{ Stmt_for_body3[i0, i1] -> schedule[0, i0, 0, i1, 0] }"
 </pre>
 The jscop file describing the tiling transformation is:
 <pre>
-"schedule" : "{ Stmt_for_body3[i0, i1] -> scattering[0, o0, o1, o2, o3]:
+"schedule" : "{ Stmt_for_body3[i0, i1] -> schedule[0, o0, o1, o2, o3]:
               o0 >= 0 and o0 <= 7 and o1 >= 0 and o1 <= 15 and
               o2 >= 0 and o2 <= 7 and o3 >= 0 and o3 <= 15 and
               i0 = 16o0 + o1 and i1 = 16o2 + o3 }"

Modified: polly/trunk/www/example_manual_matmul.html
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/www/example_manual_matmul.html?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/www/example_manual_matmul.html (original)
+++ polly/trunk/www/example_manual_matmul.html Tue Apr 21 06:37:25 2015
@@ -116,8 +116,8 @@ Printing analysis 'Polly - Create polyhe
    	Stmt_5
            Domain :=
                { Stmt_5[i0, i1] : i0 >= 0 and i0 <= 1023 and i1 >= 0 and i1 <= 1023 };
-           Scattering :=
-               { Stmt_5[i0, i1] -> scattering[0, i0, 0, i1, 0] };
+           Schedule :=
+               { Stmt_5[i0, i1] -> schedule[0, i0, 0, i1, 0] };
            WriteAccess :=
                { Stmt_5[i0, i1] -> MemRef_A[1037i0 + i1] };
            WriteAccess :=
@@ -125,8 +125,8 @@ Printing analysis 'Polly - Create polyhe
    	FinalRead
            Domain :=
                { FinalRead[0] };
-           Scattering :=
-               { FinalRead[i0] -> scattering[200000000, o1, o2, o3, o4] };
+           Schedule :=
+               { FinalRead[i0] -> schedule[200000000, o1, o2, o3, o4] };
            ReadAccess :=
                { FinalRead[i0] -> MemRef_A[o0] };
            ReadAccess :=
@@ -141,15 +141,15 @@ Printing analysis 'Polly - Create polyhe
    	Stmt_4
            Domain :=
                { Stmt_4[i0, i1] : i0 >= 0 and i0 <= 1023 and i1 >= 0 and i1 <= 1023 };
-           Scattering :=
-               { Stmt_4[i0, i1] -> scattering[0, i0, 0, i1, 0, 0, 0] };
+           Schedule :=
+               { Stmt_4[i0, i1] -> schedule[0, i0, 0, i1, 0, 0, 0] };
            WriteAccess :=
                { Stmt_4[i0, i1] -> MemRef_C[1067i0 + i1] };
    	Stmt_6
            Domain :=
                { Stmt_6[i0, i1, i2] : i0 >= 0 and i0 <= 1023 and i1 >= 0 and i1 <= 1023 and i2 >= 0 and i2 <= 1023 };
-           Scattering :=
-               { Stmt_6[i0, i1, i2] -> scattering[0, i0, 0, i1, 1, i2, 0] };
+           Schedule :=
+               { Stmt_6[i0, i1, i2] -> schedule[0, i0, 0, i1, 1, i2, 0] };
            ReadAccess :=
                { Stmt_6[i0, i1, i2] -> MemRef_C[1067i0 + i1] };
            ReadAccess :=
@@ -161,8 +161,8 @@ Printing analysis 'Polly - Create polyhe
    	FinalRead
            Domain :=
                { FinalRead[0] };
-           Scattering :=
-               { FinalRead[i0] -> scattering[200000000, o1, o2, o3, o4, o5, o6] };
+           Schedule :=
+               { FinalRead[i0] -> schedule[200000000, o1, o2, o3, o4, o5, o6] };
            ReadAccess :=
                { FinalRead[i0] -> MemRef_C[o0] };
            ReadAccess :=

Modified: polly/trunk/www/experiments/matmul/init_array___%for.cond---%for.end19.jscop
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/www/experiments/matmul/init_array___%25for.cond---%25for.end19.jscop?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/www/experiments/matmul/init_array___%for.cond---%for.end19.jscop (original)
+++ polly/trunk/www/experiments/matmul/init_array___%for.cond---%for.end19.jscop Tue Apr 21 06:37:25 2015
@@ -15,7 +15,7 @@
          ],
          "domain" : "{ Stmt_for_body3[i0, i1] : i0 >= 0 and i0 <= 1535 and i1 >= 0 and i1 <= 1535 }",
          "name" : "Stmt_for_body3",
-         "schedule" : "{ Stmt_for_body3[i0, i1] -> scattering[0, i0, 0, i1, 0] }"
+         "schedule" : "{ Stmt_for_body3[i0, i1] -> schedule[0, i0, 0, i1, 0] }"
       }
    ]
 }

Modified: polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/www/experiments/matmul/main___%25for.cond---%25for.end30.jscop?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop (original)
+++ polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop Tue Apr 21 06:37:25 2015
@@ -11,7 +11,7 @@
          ],
          "domain" : "{ Stmt_for_body3[i0, i1] : i0 >= 0 and i0 <= 1535 and i1 >= 0 and i1 <= 1535 }",
          "name" : "Stmt_for_body3",
-         "schedule" : "{ Stmt_for_body3[i0, i1] -> scattering[0, i0, 0, i1, 0, 0, 0] }"
+         "schedule" : "{ Stmt_for_body3[i0, i1] -> schedule[0, i0, 0, i1, 0, 0, 0] }"
       },
       {
          "accesses" : [
@@ -34,7 +34,7 @@
          ],
          "domain" : "{ Stmt_for_body8[i0, i1, i2] : i0 >= 0 and i0 <= 1535 and i1 >= 0 and i1 <= 1535 and i2 >= 0 and i2 <= 1535 }",
          "name" : "Stmt_for_body8",
-         "schedule" : "{ Stmt_for_body8[i0, i1, i2] -> scattering[0, i0, 0, i1, 1, i2, 0] }"
+         "schedule" : "{ Stmt_for_body8[i0, i1, i2] -> schedule[0, i0, 0, i1, 1, i2, 0] }"
       }
    ]
 }

Modified: polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop.interchanged
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/www/experiments/matmul/main___%25for.cond---%25for.end30.jscop.interchanged?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop.interchanged (original)
+++ polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop.interchanged Tue Apr 21 06:37:25 2015
@@ -11,7 +11,7 @@
          ],
          "domain" : "{ Stmt_4[i0, i1] : i0 >= 0 and i0 <= 1023 and i1 >= 0 and i1 <= 1023 }",
          "name" : "Stmt_4",
-         "schedule" : "{ Stmt_4[i0, i1] -> scattering[0, i0, 0, i1, 0, 0, 0] }"
+         "schedule" : "{ Stmt_4[i0, i1] -> schedule[0, i0, 0, i1, 0, 0, 0] }"
       },
       {
          "accesses" : [
@@ -34,7 +34,7 @@
          ],
          "domain" : "{ Stmt_6[i0, i1, i2] : i0 >= 0 and i0 <= 1023 and i1 >= 0 and i1 <= 1023 and i2 >= 0 and i2 <= 1023 }",
          "name" : "Stmt_6",
-         "schedule" : "{ Stmt_6[i0, i1, i2] -> scattering[1, i0, 0, i2, 0, i1, 0] }"
+         "schedule" : "{ Stmt_6[i0, i1, i2] -> schedule[1, i0, 0, i2, 0, i1, 0] }"
       }
    ]
 }

Modified: polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop.interchanged+tiled
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/www/experiments/matmul/main___%25for.cond---%25for.end30.jscop.interchanged%2Btiled?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop.interchanged+tiled (original)
+++ polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop.interchanged+tiled Tue Apr 21 06:37:25 2015
@@ -11,7 +11,7 @@
          ],
          "domain" : "{ Stmt_4[i0, i1] : i0 >= 0 and i0 <= 1023 and i1 >= 0 and i1 <= 1023 }",
          "name" : "Stmt_4",
-         "schedule" : "{ Stmt_4[i0, i1] -> scattering[0, i0, 0, i1, 0, 0, 0] }"
+         "schedule" : "{ Stmt_4[i0, i1] -> schedule[0, i0, 0, i1, 0, 0, 0] }"
       },
       {
          "accesses" : [
@@ -34,7 +34,7 @@
          ],
          "domain" : "{ Stmt_6[i0, i1, i2] : i0 >= 0 and i0 <= 1023 and i1 >= 0 and i1 <= 1023 and i2 >= 0 and i2 <= 1023 }",
          "name" : "Stmt_6",
-         "schedule" : "{ Stmt_6[i0, i1, i2] -> scattering[1, o0, o1, o2, i0, i2, i1]: o0 <= i0 < o0 + 64 and o1 <= i1 < o1 + 64 and o2 <= i2 < o2 + 64 and o0 % 64 = 0 and o1 % 64 = 0 and o2 % 64 = 0 }"
+         "schedule" : "{ Stmt_6[i0, i1, i2] -> schedule[1, o0, o1, o2, i0, i2, i1]: o0 <= i0 < o0 + 64 and o1 <= i1 < o1 + 64 and o2 <= i2 < o2 + 64 and o0 % 64 = 0 and o1 % 64 = 0 and o2 % 64 = 0 }"
       }
    ]
 }

Modified: polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop.interchanged+tiled+vector
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/www/experiments/matmul/main___%25for.cond---%25for.end30.jscop.interchanged%2Btiled%2Bvector?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop.interchanged+tiled+vector (original)
+++ polly/trunk/www/experiments/matmul/main___%for.cond---%for.end30.jscop.interchanged+tiled+vector Tue Apr 21 06:37:25 2015
@@ -11,7 +11,7 @@
          ],
          "domain" : "{ Stmt_4[i0, i1] : i0 >= 0 and i0 <= 1023 and i1 >= 0 and i1 <= 1023 }",
          "name" : "Stmt_4",
-         "schedule" : "{ Stmt_4[i0, i1] -> scattering[0, i0, 0, i1, 0, 0, 0, 0] }"
+         "schedule" : "{ Stmt_4[i0, i1] -> schedule[0, i0, 0, i1, 0, 0, 0, 0] }"
       },
       {
          "accesses" : [
@@ -34,7 +34,7 @@
          ],
          "domain" : "{ Stmt_6[i0, i1, i2] : i0 >= 0 and i0 <= 1023 and i1 >= 0 and i1 <= 1023 and i2 >= 0 and i2 <= 1023 }",
          "name" : "Stmt_6",
-         "schedule" : "{ Stmt_6[i0, i1, i2] -> scattering[1, o0, o1, o2, i0, i2, ii1, i1]: o0 <= i0 < o0 + 64 and o1 <= i1 < o1 + 64 and o2 <= i2 < o2 + 64 and o0 % 64 = 0 and o1 % 64 = 0 and o2 % 64 = 0 and ii1 % 4 = 0 and ii1 <= i1 < ii1 + 4}"
+         "schedule" : "{ Stmt_6[i0, i1, i2] -> schedule[1, o0, o1, o2, i0, i2, ii1, i1]: o0 <= i0 < o0 + 64 and o1 <= i1 < o1 + 64 and o2 <= i2 < o2 + 64 and o0 % 64 = 0 and o1 % 64 = 0 and o2 % 64 = 0 and ii1 % 4 = 0 and ii1 <= i1 < ii1 + 4}"
       }
    ]
 }





More information about the llvm-commits mailing list
--- polly/trunk/include/polly/DependenceInfo.h (original)
+++ polly/trunk/include/polly/DependenceInfo.h Tue Apr 21 06:37:25 2015
@@ -105,7 +105,7 @@ struct Dependences {
 
   /// @brief Check if a partial schedule is parallel wrt to @p Deps.
   ///
-  /// @param Schedule       The subset of the scattering space that we want to
+  /// @param Schedule       The subset of the schedule space that we want to
   ///                       check.
   /// @param Deps           The dependences @p Schedule needs to respect.
   /// @param MinDistancePtr If not nullptr, the minimal dependence distance will
@@ -117,14 +117,14 @@ struct Dependences {
                   __isl_take isl_union_map *Deps,
                   __isl_give isl_pw_aff **MinDistancePtr = nullptr) const;
 
   /// @brief Check if a new scattering is valid.
   ///
   /// @param S             The current SCoP.
-  /// @param NewScattering The new scatterings
+  /// @param NewSchedules  The new schedules
   ///
   /// @return bool True if the new scattering is valid, false it it reverses
   ///              dependences.
-  bool isValidScattering(Scop &S, StatementToIslMapTy *NewScatterings) const;
+  bool isValidSchedule(Scop &S, StatementToIslMapTy *NewSchedules) const;
 
   /// @brief Print the dependence information stored.
   void print(llvm::raw_ostream &OS) const;
@@ -117,14 +117,14 @@ struct Dependences {
                   __isl_give isl_pw_aff **MinDistancePtr = nullptr) const;
 
-  /// @brief Check if a new scattering is valid.
+  /// @brief Check if a new schedule is valid.
   ///
   /// @param S             The current SCoP.
@@ -117,14 +117,14 @@ struct Dependences {
   ///
-  /// @return bool True if the new scattering is valid, false it it reverses
+  /// @return bool True if the new schedule is valid, false it it reverses
   ///              dependences.

Modified: polly/trunk/include/polly/ScopInfo.h
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/include/polly/ScopInfo.h?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/include/polly/ScopInfo.h (original)
+++ polly/trunk/include/polly/ScopInfo.h Tue Apr 21 06:37:25 2015
@@ -422,35 +422,35 @@ class ScopStmt {
   /// instance.
   isl_set *Domain;
 
   /// The scattering map describes the execution order of the statement
   /// instances.
   ///
   /// A statement and its iteration domain do not give any information about the
   /// order in time in which the different statement instances are executed.
   /// This information is provided by the scattering.
   ///
   /// The scattering maps every instance of each statement into a multi
   /// dimensional scattering space. This space can be seen as a multi
   /// dimensional clock.
   ///
   /// Example:
   ///
   /// <S,(5,4)>  may be mapped to (5,4) by this scattering:
   ///
   /// s0 = i (Year of execution)
   /// s1 = j (Day of execution)
   ///
   /// or to (9, 20) by this scattering:
   ///
   /// s0 = i + j (Year of execution)
   /// s1 = 20 (Day of execution)
   ///
   /// The order statement instances are executed is defined by the
   /// scattering vectors they are mapped to. A statement instance
   /// <A, (i, j, ..)> is executed before a statement instance <B, (i', ..)>, if
   /// the scattering vector of A is lexicographic smaller than the scattering
   /// vector of B.
-  isl_map *Scattering;
+  isl_map *Schedule;
 
   /// The memory accesses of this statement.
   ///
@@ -492,7 +492,7 @@ class ScopStmt {
   __isl_give isl_set *addLoopBoundsToDomain(__isl_take isl_set *Domain,
                                             TempScop &tempScop);
   __isl_give isl_set *buildDomain(TempScop &tempScop, const Region &CurRegion);
-  void buildScattering(SmallVectorImpl<unsigned> &Scatter);
+  void buildSchedule(SmallVectorImpl<unsigned> &ScheduleVec);
 
   /// @brief Create the accesses for instructions in @p Block.
   ///
@@ -549,12 +549,12 @@ class ScopStmt {
   /// Create the ScopStmt from a BasicBlock.
   ScopStmt(Scop &parent, TempScop &tempScop, const Region &CurRegion,
            BasicBlock &bb, SmallVectorImpl<Loop *> &NestLoops,
-           SmallVectorImpl<unsigned> &Scatter);
+           SmallVectorImpl<unsigned> &ScheduleVec);
 
   /// Create an overapproximating ScopStmt for the region @p R.
   ScopStmt(Scop &parent, TempScop &tempScop, const Region &CurRegion, Region &R,
            SmallVectorImpl<Loop *> &NestLoops,
-           SmallVectorImpl<unsigned> &Scatter);
+           SmallVectorImpl<unsigned> &ScheduleVec);
 
   friend class Scop;
 
@@ -582,14 +582,14 @@ public:
   /// @brief Get an isl string representing this domain.
   std::string getDomainStr() const;
 
   /// @brief Get the scattering function of this ScopStmt.
   ///
-  /// @return The scattering function of this ScopStmt.
-  __isl_give isl_map *getScattering() const;
-  void setScattering(__isl_take isl_map *scattering);
+  /// @return The schedule function of this ScopStmt.
+  __isl_give isl_map *getSchedule() const;
+  void setSchedule(__isl_take isl_map *Schedule);
 
-  /// @brief Get an isl string representing this scattering.
-  std::string getScatteringStr() const;
+  /// @brief Get an isl string representing this schedule.
+  std::string getScheduleStr() const;
 
   /// @brief Get the BasicBlock represented by this ScopStmt (if any).
   ///
@@ -638,7 +638,7 @@ public:
 
   unsigned getNumParams() const;
   unsigned getNumIterators() const;
-  unsigned getNumScattering() const;
+  unsigned getNumSchedule() const;
 
   Scop *getParent() { return &Parent; }
   const Scop *getParent() const { return &Parent; }
@@ -807,17 +807,17 @@ private:
   /// @param tempScop   The temp SCoP we use as model.
   /// @param CurRegion  The SCoP region.
   /// @param NestLoops  A vector of all surrounding loops.
   /// @param Scatter    The position of the new statement as scattering.
   void addScopStmt(BasicBlock *BB, Region *R, TempScop &tempScop,
                    const Region &CurRegion, SmallVectorImpl<Loop *> &NestLoops,
-                   SmallVectorImpl<unsigned> &Scatter);
+                   SmallVectorImpl<unsigned> &Schedule);
 
   /// Build the Scop and Statement with precalculated scop information.
   void buildScop(TempScop &TempScop, const Region &CurRegion,
                  // Loops in Scop containing CurRegion
                  SmallVectorImpl<Loop *> &NestLoops,
-                 // The scattering numbers
-                 SmallVectorImpl<unsigned> &Scatter, LoopInfo &LI,
+                 // The schedule numbers
+                 SmallVectorImpl<unsigned> &Schedule, LoopInfo &LI,
                  ScopDetection &SD);
 
   /// @name Helper function for printing the Scop.
@@ -881,16 +881,16 @@ public:
   /// @return The maximum depth of the loop.
   inline unsigned getMaxLoopDepth() const { return MaxLoopDepth; }
 
   /// @brief Get the scattering dimension number of this Scop.
   ///
-  /// @return The scattering dimension number of this Scop.
-  inline unsigned getScatterDim() const {
-    unsigned maxScatterDim = 0;
+  /// @return The schedule dimension number of this Scop.
+  inline unsigned getScheduleDim() const {
+    unsigned maxScheduleDim = 0;
 
     for (const_iterator SI = begin(), SE = end(); SI != SE; ++SI)
-      maxScatterDim = std::max(maxScatterDim, (*SI)->getNumScattering());
+      maxScheduleDim = std::max(maxScheduleDim, (*SI)->getNumSchedule());
 
-    return maxScatterDim;
+    return maxScheduleDim;
   }
 
   /// @brief Mark the SCoP as optimized by the scheduler.
@@ -937,7 +937,7 @@ public:
   ///
   ///  Schedule dimensions that are constant accross the scop do not carry
   ///  any information, but would cost compile time due to the increased number
   ///  of scheduling dimensions. To not pay this cost, we remove them.
   void dropConstantScheduleDims();
 
   /// @brief Return all alias groups for this SCoP.
@@ -422,35 +422,35 @@ class ScopStmt {
   isl_set *Domain;
 
-  /// The scattering map describes the execution order of the statement
+  /// The schedule map describes the execution order of the statement
   /// instances.
   ///
@@ -422,35 +422,35 @@ class ScopStmt {
   /// A statement and its iteration domain do not give any information about the
   /// order in time in which the different statement instances are executed.
-  /// This information is provided by the scattering.
+  /// This information is provided by the schedule.
   ///
@@ -422,35 +422,35 @@ class ScopStmt {
   ///
-  /// The scattering maps every instance of each statement into a multi
-  /// dimensional scattering space. This space can be seen as a multi
+  /// The schedule maps every instance of each statement into a multi
+  /// dimensional schedule space. This space can be seen as a multi
   /// dimensional clock.
   ///
@@ -422,35 +422,35 @@ class ScopStmt {
   /// Example:
   ///
-  /// <S,(5,4)>  may be mapped to (5,4) by this scattering:
+  /// <S,(5,4)>  may be mapped to (5,4) by this schedule:
   ///
   /// s0 = i (Year of execution)
@@ -422,35 +422,35 @@ class ScopStmt {
   /// s1 = j (Day of execution)
   ///
-  /// or to (9, 20) by this scattering:
+  /// or to (9, 20) by this schedule:
   ///
   /// s0 = i + j (Year of execution)
@@ -422,35 +422,35 @@ class ScopStmt {
   ///
   /// The order statement instances are executed is defined by the
-  /// scattering vectors they are mapped to. A statement instance
+  /// schedule vectors they are mapped to. A statement instance
   /// <A, (i, j, ..)> is executed before a statement instance <B, (i', ..)>, if
@@ -422,35 +422,35 @@ class ScopStmt {
   /// <A, (i, j, ..)> is executed before a statement instance <B, (i', ..)>, if
-  /// the scattering vector of A is lexicographic smaller than the scattering
+  /// the schedule vector of A is lexicographic smaller than the schedule
   /// vector of B.
@@ -582,14 +582,14 @@ public:
   std::string getDomainStr() const;
 
-  /// @brief Get the scattering function of this ScopStmt.
+  /// @brief Get the schedule function of this ScopStmt.
   ///
@@ -807,17 +807,17 @@ private:
   /// @param CurRegion  The SCoP region.
   /// @param NestLoops  A vector of all surrounding loops.
-  /// @param Scatter    The position of the new statement as scattering.
+  /// @param Schedule   The position of the new statement as schedule.
   void addScopStmt(BasicBlock *BB, Region *R, TempScop &tempScop,
                    const Region &CurRegion, SmallVectorImpl<Loop *> &NestLoops,
@@ -881,16 +881,16 @@ public:
   inline unsigned getMaxLoopDepth() const { return MaxLoopDepth; }
 
-  /// @brief Get the scattering dimension number of this Scop.
+  /// @brief Get the schedule dimension number of this Scop.
   ///
@@ -937,7 +937,7 @@ public:
   ///  Schedule dimensions that are constant accross the scop do not carry
   ///  any information, but would cost compile time due to the increased number
-  ///  of scheduling dimensions. To not pay this cost, we remove them.
+  ///  of schedule dimensions. To not pay this cost, we remove them.
   void dropConstantScheduleDims();
 

Modified: polly/trunk/lib/Analysis/DependenceInfo.cpp
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/Analysis/DependenceInfo.cpp?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================
--- polly/trunk/lib/Analysis/DependenceInfo.cpp (original)
+++ polly/trunk/lib/Analysis/DependenceInfo.cpp Tue Apr 21 06:37:25 2015
@@ -91,23 +91,23 @@ static void collectInfo(Scop &S, isl_uni
       accdom = isl_map_intersect_domain(accdom, domcp);
 
       if (ReductionBaseValues.count(MA->getBaseAddr())) {
         // Wrap the access domain and adjust the scattering accordingly.
         //
         // An access domain like
         //   Stmt[i0, i1] -> MemAcc_A[i0 + i1]
         // will be transformed into
         //   [Stmt[i0, i1] -> MemAcc_A[i0 + i1]] -> MemAcc_A[i0 + i1]
         //
         // The original scattering looks like
         //   Stmt[i0, i1] -> [0, i0, 2, i1, 0]
         // but as we transformed the access domain we need the scattering
         // to match the new access domains, thus we need
         //   [Stmt[i0, i1] -> MemAcc_A[i0 + i1]] -> [0, i0, 2, i1, 0]
-        isl_map *Scatter = Stmt->getScattering();
-        Scatter = isl_map_apply_domain(
-            Scatter, isl_map_reverse(isl_map_domain_map(isl_map_copy(accdom))));
+        isl_map *Schedule = Stmt->getSchedule();
+        Schedule = isl_map_apply_domain(
+            Schedule, isl_map_reverse(isl_map_domain_map(isl_map_copy(accdom))));
         accdom = isl_map_range_map(accdom);
-        *AccessSchedule = isl_union_map_add_map(*AccessSchedule, Scatter);
+        *AccessSchedule = isl_union_map_add_map(*AccessSchedule, Schedule);
       }
 
       if (MA->isRead())
@@ -115,7 +115,7 @@ static void collectInfo(Scop &S, isl_uni
       else
         *Write = isl_union_map_add_map(*Write, accdom);
     }
-    *StmtSchedule = isl_union_map_add_map(*StmtSchedule, Stmt->getScattering());
+    *StmtSchedule = isl_union_map_add_map(*StmtSchedule, Stmt->getSchedule());
   }
 
   *StmtSchedule =
@@ -463,41 +463,41 @@ void Dependences::calculateDependences(S
   DEBUG(dump());
 }
 
-bool Dependences::isValidScattering(Scop &S,
-                                    StatementToIslMapTy *NewScattering) const {
+bool Dependences::isValidSchedule(Scop &S,
+                                    StatementToIslMapTy *NewSchedule) const {
   if (LegalityCheckDisabled)
     return true;
 
   isl_union_map *Dependences = getDependences(TYPE_RAW | TYPE_WAW | TYPE_WAR);
   isl_space *Space = S.getParamSpace();
-  isl_union_map *Scattering = isl_union_map_empty(Space);
+  isl_union_map *Schedule = isl_union_map_empty(Space);
 
-  isl_space *ScatteringSpace = nullptr;
+  isl_space *ScheduleSpace = nullptr;
 
   for (ScopStmt *Stmt : S) {
     isl_map *StmtScat;
 
-    if (NewScattering->find(Stmt) == NewScattering->end())
-      StmtScat = Stmt->getScattering();
+    if (NewSchedule->find(Stmt) == NewSchedule->end())
+      StmtScat = Stmt->getSchedule();
     else
-      StmtScat = isl_map_copy((*NewScattering)[Stmt]);
+      StmtScat = isl_map_copy((*NewSchedule)[Stmt]);
 
-    if (!ScatteringSpace)
-      ScatteringSpace = isl_space_range(isl_map_get_space(StmtScat));
+    if (!ScheduleSpace)
+      ScheduleSpace = isl_space_range(isl_map_get_space(StmtScat));
 
-    Scattering = isl_union_map_add_map(Scattering, StmtScat);
+    Schedule = isl_union_map_add_map(Schedule, StmtScat);
   }
 
   Dependences =
-      isl_union_map_apply_domain(Dependences, isl_union_map_copy(Scattering));
-  Dependences = isl_union_map_apply_range(Dependences, Scattering);
+      isl_union_map_apply_domain(Dependences, isl_union_map_copy(Schedule));
+  Dependences = isl_union_map_apply_range(Dependences, Schedule);
 
-  isl_set *Zero = isl_set_universe(isl_space_copy(ScatteringSpace));
+  isl_set *Zero = isl_set_universe(isl_space_copy(ScheduleSpace));
   for (unsigned i = 0; i < isl_set_dim(Zero, isl_dim_set); i++)
     Zero = isl_set_fix_si(Zero, isl_dim_set, i, 0);
 
   isl_union_set *UDeltas = isl_union_map_deltas(Dependences);
-  isl_set *Deltas = isl_union_set_extract_set(UDeltas, ScatteringSpace);
+  isl_set *Deltas = isl_union_set_extract_set(UDeltas, ScheduleSpace);
   isl_union_set_free(UDeltas);
 
   isl_map *NonPositive = isl_set_lex_le_set(Deltas, Zero);
@@ -91,23 +91,23 @@ static void collectInfo(Scop &S, isl_uni
 
       if (ReductionBaseValues.count(MA->getBaseAddr())) {
-        // Wrap the access domain and adjust the scattering accordingly.
+        // Wrap the access domain and adjust the schedule accordingly.
         //
         // An access domain like
@@ -91,23 +91,23 @@ static void collectInfo(Scop &S, isl_uni
         //   [Stmt[i0, i1] -> MemAcc_A[i0 + i1]] -> MemAcc_A[i0 + i1]
         //
-        // The original scattering looks like
+        // The original schedule looks like
         //   Stmt[i0, i1] -> [0, i0, 2, i1, 0]
@@ -91,23 +91,23 @@ static void collectInfo(Scop &S, isl_uni
         //   Stmt[i0, i1] -> [0, i0, 2, i1, 0]
-        // but as we transformed the access domain we need the scattering
+        // but as we transformed the access domain we need the schedule
         // to match the new access domains, thus we need
         //   [Stmt[i0, i1] -> MemAcc_A[i0 + i1]] -> [0, i0, 2, i1, 0]

Modified: polly/trunk/lib/Analysis/ScopInfo.cpp
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/Analysis/ScopInfo.cpp?rev=235380&r1=235379&r2=235380&view=diff
==============================================================================